from raga import *
import datetime

run_name = f"AB-event-unlabelled-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
test_session = TestSession(project_name="testingProject", run_name = run_name, access_key="LGXJjQFD899MtVSrNHGH", secret_key="TC466Qu9PhpOjTuLu5aGkXyGbM7SSBeAzYH6HpcP", host="http://3.111.106.226:8080")


rules = EventABTestRules() 
rules.add(metric = "difference_percentage", IoU = 0.5, _class = "ALL", threshold = 0.5, conf_threshold=0.5)
rules.add(metric = "difference_count", IoU = 0.5, _class = "ALL", threshold = 0.5, conf_threshold=0.5)

model_comparison_check = event_ab_test(test_session=test_session, 
                                       dataset_name="stopsign-event-video-ds-full-v5",
                                       test_name="AB-test-unlabelled",
                                       model = "Production-America-Stop-Event",
                                       gt = "Complex-America-Stop-Event",
                                       object_detection_model="Complex-America-Stop-Model",
                                       object_detection_gt = "Production-America-Stop-Model",
                                       type = "metadata", 
                                       sub_type = "unlabelled", 
                                       output_type = "event_detection",
                                       rules = rules,
                                       aggregation_level=["weather"])

# add payload into test_session object
test_session.add(model_comparison_check)
#run added test
test_session.run()


from raga import *
import pandas as pd
import datetime

def get_timestamp_x_hours_ago(hours):
    current_time = datetime.datetime.now()
    delta = datetime.timedelta(days=90, hours=hours)
    past_time = current_time - delta
    timestamp = int(past_time.timestamp())
    return timestamp

def image_id(row):
    file = row["SourceLink"].split("/")[-1]
    return StringElement(file)

def csv_parser(csv_file):
    df = pd.read_csv(csv_file)
    data_frame = pd.DataFrame()
    data_frame["ImageId"] = df.apply(image_id , axis=1)
    data_frame["ImageUri"] = df["SourceLink"].apply(lambda x: StringElement(f"https://product-uploads-raga.s3.ap-south-1.amazonaws.com/data/{x.split('/')[-1]}"))
    return data_frame.head(100)

###################################################################################################
pd_data_frame = csv_parser("./assets/labelling_qc_score_df-copy.csv")


schema = RagaSchema()
schema.add("ImageId", PredictionSchemaElement())
schema.add("ImageUri", ImageUriSchemaElement())

run_name = f"Pre-UAT-DS-29sep-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
test_session = TestSession(project_name="testingProject", run_name= run_name, access_key="LGXJjQFD899MtVSrNHGH", secret_key="TC466Qu9PhpOjTuLu5aGkXyGbM7SSBeAzYH6HpcP", host="http://3.111.106.226:8080")

cred = DatasetCreds(arn="arn:aws:iam::527593518644:role/raga-importer")

#create test_ds object of Dataset instance
test_ds = Dataset(test_session=test_session,
                  name="Pre-UAT-DS-29sep-v3",
                  type=DATASET_TYPE.IMAGE,
                  data=pd_data_frame, 
                  schema=schema, 
                  creds=cred)

#load to server
test_ds.load()


import ast
from raga import *
import pandas as pd
import datetime

def get_timestamp_x_hours_ago(hours):
    current_time = datetime.datetime.now()
    delta = datetime.timedelta(days=90, hours=hours)
    past_time = current_time - delta
    timestamp = int(past_time.timestamp())
    return timestamp

def image_classification(x):
    classification = ImageClassificationElement()
    x = ast.literal_eval(x)
    for key, value in x.items():
        classification.add(key=key, value=value)
    return classification

def mistake_score(x):
    mistake_score = MistakeScore()
    x = ast.literal_eval(x)
    for key, value in x.items():
        mistake_score.add(key=key, value=value, area=0)
    return mistake_score

def image_id(index, row):
    file = row["SourceLink"].split("/")[-1]
    return StringElement(f"{index}_{file}".replace(" ", "_"))

def replace_embedding(x):
    embeddings = ImageEmbedding()
    for embedding in x:
        embeddings.add(Embedding(embedding))
    return embeddings

def csv_parser(csv_file, embedding_file):
    df = pd.read_csv(csv_file).head(100)
    embeddings = pd.read_json(embedding_file)
    merged_df = pd.merge(df, embeddings, left_on="SourceLink", right_on="filepath", how="inner")
    data_frame = pd.DataFrame()
    data_frame["ImageId"] = merged_df.apply(lambda x: image_id(x.name, x) , axis=1)
    data_frame["ImageUri"] = merged_df["SourceLink"].apply(lambda x: StringElement(f"https://ragatesitng-dev-storage.s3.ap-south-1.amazonaws.com/1{x.replace('100_sports_dataset', '')}"))
    data_frame["SourceLink"] = merged_df["SourceLink"].apply(lambda x: StringElement(x))
    data_frame["TimeOfCapture"] = merged_df.apply(lambda row: TimeStampElement(get_timestamp_x_hours_ago(row.name)), axis=1)
    data_frame["GroundTruth"] = merged_df["Ground Truth"].apply(image_classification)
    data_frame["MistakeScore"] = merged_df["mistake_score"].apply(mistake_score)
    data_frame["ImageVectorsM1"] = merged_df['embedding'].apply(lambda x:replace_embedding(x))
    return data_frame

pd_data_frame = csv_parser("./assets/labelling_qc_score_df.csv", "./assets/train.json")

#### Want to see in csv file uncomment line below ####
# data_frame_extractor(pd_data_frame).to_csv("./assets/labelling_qc_score_df_test_embeddings.csv", index=False)

schema = RagaSchema()
schema.add("ImageId", PredictionSchemaElement())
schema.add("ImageUri", ImageUriSchemaElement())
schema.add("TimeOfCapture", TimeOfCaptureSchemaElement())
schema.add("SourceLink", FeatureSchemaElement())
schema.add("GroundTruth", ImageClassificationSchemaElement(model="GT"))
schema.add("MistakeScore", MistakeScoreSchemaElement(ref_col_name="GroundTruth"))
schema.add("ImageVectorsM1", ImageEmbeddingSchemaElement(model="imageModel1"))

run_name = f"loader_labeling_quality_image_classification-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
# test_session = TestSession(project_name="testingProject", run_name= run_name, access_key="LGXJjQFD899MtVSrNHGH", secret_key="TC466Qu9PhpOjTuLu5aGkXyGbM7SSBeAzYH6HpcP", host="http://3.111.106.226:8080")
test_session = TestSession(project_name="testingProject", run_name= run_name, access_key="qGIXoxPVMObBs9DzBXuX", secret_key="VqpODChJcTi3QHWmr4PZiX6D1aXxid7QSd7YKpyJ", host="http://prod-raga.ragaai.in")

cred = DatasetCreds(arn="arn:aws:iam::527593518644:role/s3-role")

#create test_ds object of Dataset instance
test_ds = Dataset(test_session=test_session,
                  name="100-sport-dataset-100-v2",
                  type=DATASET_TYPE.IMAGE,
                  data=pd_data_frame, 
                  schema=schema, 
                  creds=cred)

#load to server
test_ds.load()


import ast
import random
from raga import *
import pandas as pd
import datetime

def get_timestamp_x_hours_ago(hours):
    current_time = datetime.datetime.now()
    delta = datetime.timedelta(days=90, hours=hours)
    past_time = current_time - delta
    timestamp = int(past_time.timestamp())
    return timestamp

def csv_parser(csv_path):
    data_frame = pd.read_csv(csv_path)
    df = pd.DataFrame()
    df["ImageId"] = data_frame["image_id"].apply(lambda x: StringElement(x))
    df["ImageUri"] = data_frame['lr_path'].apply(lambda x: StringElement(x))
    df["TimeOfCapture"] = data_frame.apply(lambda row: TimeStampElement(get_timestamp_x_hours_ago(row.name)), axis=1)
    df["SourceLink"] = data_frame['image_name'].apply(lambda x:StringElement(x))
    df["SuperImageUri"] = data_frame['hr_path'].apply(lambda x: StringElement(x))
    return df


pd_data_frame = csv_parser("./assets/super_resolution_data.csv")

#### Want to see in csv file uncomment line below ####
data_frame_extractor(pd_data_frame).to_csv("./assets/super_resolution_data_test_1.csv")

schema = RagaSchema()
schema.add("ImageId", PredictionSchemaElement())
schema.add("ImageUri", ImageUriSchemaElement())
schema.add("TimeOfCapture", TimeOfCaptureSchemaElement())
schema.add("SourceLink", FeatureSchemaElement())
schema.add("SuperImageUri", BlobSchemaElement())





run_name = f"loader_failure_mode_analysis_semantic_segmentation-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
test_session = TestSession(project_name="testingProject", run_name= run_name)
cred = DatasetCreds(arn="arn:aws:iam::527593518644:role/model-distribution")

#create test_ds object of Dataset instance
test_ds = Dataset(test_session=test_session,
                  name="super_resolution_data_v2",
                  type=DATASET_TYPE.IMAGE,
                  data=pd_data_frame,
                  schema=schema,
                  creds=cred)

#load to server
test_ds.load()

model_exe_fun = ModelExecutorFactory().get_model_executor(test_session=test_session, 
                                                          model_name="Satsure Embedding Model", 
                                                          version="0.1.1")

df = model_exe_fun.execute(init_args={"device": "cpu", "frame_sampling_rate":1}, 
                        execution_args={"input_columns":{"img_paths":"ImageUri"}, 
                                        "output_columns":{"embedding":"imageEmbedding"},
                                        "column_schemas":{"embedding":ImageEmbeddingSchemaElement(model="Satsure Embedding Model")}}, 
                        data_frame=test_ds)

print(df)
test_ds.load()


from raga import *
import datetime

run_name = f"drift-test-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
test_session = TestSession(project_name="testingProject", run_name = run_name, access_key="LGXJjQFD899MtVSrNHGH", secret_key="TC466Qu9PhpOjTuLu5aGkXyGbM7SSBeAzYH6HpcP", host="http://3.111.106.226:8080")

rules = DriftDetectionRules()
rules.add(type="anomaly_detection", dist_metric="Mahalanobis", _class="ALL", threshold=0.6)

# edge_case_detection = data_drift_detection(test_session=test_session,
#                                            test_name="Drift-detection-test",
#                                            train_dataset_name="grassLands-v1",
#                                            field_dataset_name="barrenland_v1",
#                                            train_embed_col_name="Annotations",
#                                            field_embed_col_name = "Annotations",
#                                            output_type = "semantic_segmentation",
#                                            level = "image",
#                                            aggregation_level=["location", "vehicle_no", "channel"],
#                                            rules = rules)

# edge_case_detection = data_drift_detection(test_session=test_session,
#                                            test_name="Drift-detection-test",
#                                            train_dataset_name="grasslands-v1",
#                                            field_dataset_name="barrenlands-v1",
#                                            train_embed_col_name="ImageVectorsM1",
#                                            field_embed_col_name = "ImageVectorsM1",
#                                            output_type = "semantic_segmentation",
#                                            level = "image",
#                                            rules = rules)

edge_case_detection = data_drift_detection(test_session=test_session,
                                           test_name="Drift-detection-test",
                                           dataset_name="super_resolution_data_v1",
                                           embed_col_name="imageEmbedding",
                                           output_type = "super_resolution",
                                           rules = rules)

# add payload into test_session object
test_session.add(edge_case_detection)
#run added test
test_session.run()



import ast
import random
from raga import *
import pandas as pd
import datetime

label_to_classname = {
    0: "No Data",
    1: "Natural Vegetation",
    2: "Forest",
    3: "Corn",
    4: "Soybeans",
    5: "Wetlands",
    6: "Developed/Barren",
    7: "Open Water",
    8: "Winter Wheat",
    9: "Alfalfa",
    10: "Fallow/Idle Cropland",
    11: "Cotton",
    12: "Sorghum",
    13: "Other"
  }


def get_timestamp_x_hours_ago(hours):
    current_time = datetime.datetime.now()
    delta = datetime.timedelta(days=90, hours=hours)
    past_time = current_time - delta
    timestamp = int(past_time.timestamp())
    return timestamp

def image_url(x):
    return f"https://ragatesitng-dev-storage.s3.ap-south-1.amazonaws.com/1/semantic_segmentation_demo_rgb/{x}"

def gt_mask_url(x):
    tif = x.split("/")[1]
    return f"https://ragatesitng-dev-storage.s3.ap-south-1.amazonaws.com/1/semantic_segmentation_demo_label/{tif}"

def model_mask_url(x):
    tif = x.split("/")[1]
    return f"https://ragatesitng-dev-storage.s3.ap-south-1.amazonaws.com/1/semantic_segmentation_demo_output/{tif}"

def attached_label(id, loss):
    return {id:loss}

def merge_loss_dicts(x):
    mistake_score = MistakeScore()
    x = ast.literal_eval(x)
    
    for key, value in x.items():
        mistake_score.add(key=key, value=value.get('mistake_score'), area=value.get('area'))
    return mistake_score

def imag_embedding(x):
    x = ast.literal_eval(x)
    Embeddings = ImageEmbedding()
    for embedding in x:
        Embeddings.add(Embedding(embedding))
    return Embeddings

def csv_parser(file_path):
    df = pd.read_csv(file_path)
    data_frame = pd.DataFrame()
    data_frame["ImageId"] = df["id"].apply(lambda x: StringElement(x))
    data_frame["ImageUri"] = df["id"].apply(lambda x: StringElement(image_url(f"{x}_merged.tif")))
    data_frame["TimeOfCapture"] = df.apply(lambda row: TimeStampElement(get_timestamp_x_hours_ago(row.name)), axis=1)
    # data_frame["GT"] = df['ground_truth'].apply(lambda x:StringElement(gt_mask_url(x)))
    # data_frame["ModelInference"] = df['model_inference'].apply(lambda x:StringElement(model_mask_url(x)))
    data_frame["Embedding"] = df['embedding'].apply(lambda x: imag_embedding(x))
    # data_frame["MistakeScores"] = df['mistake_score'].apply(merge_loss_dicts)
    data_frame["Reflection"] = data_frame.apply(lambda row: StringElement(random.choice(["Yes", "No"])), axis=1)
    data_frame["Overlap"] = data_frame.apply(lambda row: StringElement(random.choice(["Yes", "No"])), axis=1)
    data_frame["CameraAngle"] = data_frame.apply(lambda row: StringElement(random.choice(["Yes", "No"])), axis=1)
    return data_frame


data_frame = csv_parser("./assets/field_data.csv")


schema = RagaSchema()
schema.add("ImageId", PredictionSchemaElement())
schema.add("ImageUri", ImageUriSchemaElement())
schema.add("TimeOfCapture", TimeOfCaptureSchemaElement())
# schema.add("GT", TIFFSchemaElement(label_mapping=label_to_classname, schema="tif", model="ModelGT"))
# schema.add("ModelInference", TIFFSchemaElement(label_mapping=label_to_classname, schema="tif", model="ModelA"))
schema.add("Embedding", ImageEmbeddingSchemaElement(model="imageModel"))
# schema.add("MistakeScores", MistakeScoreSchemaElement(ref_col_name="Annotations"))
schema.add('Reflection', AttributeSchemaElement())
schema.add('Overlap', AttributeSchemaElement())
schema.add('CameraAngle', AttributeSchemaElement())



run_name = f"loader_demo_semantic_segmentation-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"

# create test_session object of TestSession instance
test_session = TestSession(project_name="testingProject", run_name= run_name, access_key="LGXJjQFD899MtVSrNHGH", secret_key="TC466Qu9PhpOjTuLu5aGkXyGbM7SSBeAzYH6HpcP", host="http://3.111.106.226:8080")

cred = DatasetCreds(arn="arn:aws:iam::527593518644:role/s3-role")

#create test_ds object of Dataset instance
test_ds = Dataset(test_session=test_session, 
                  name="test_demo_field_data-v2", 
                  type=DATASET_TYPE.IMAGE,
                  data=data_frame, 
                  schema=schema)

# #load schema and pandas data frame
test_ds.load()



import ast
import pandas as pd
import json

from raga import *

import datetime

def img_url(x):
    return StringElement(f"https://raga-test-bucket.s3.ap-south-1.amazonaws.com/spoof/{x}")


def csv_parser(csv_file):
    df = pd.read_csv(csv_file).head(10)
    data_frame = pd.DataFrame()
    data_frame["ImageId"] = df["ImageId"].apply(lambda x: StringElement(x))
    data_frame["ImageUri"] = df["ImageId"].apply(lambda x: img_url(x))
    return data_frame


raga_data_frame = csv_parser("./assets/signzy_df.csv")


schema = RagaSchema()
schema.add("ImageId", PredictionSchemaElement())
schema.add("ImageUri", ImageUriSchemaElement())

run_name = f"model_distribution-{datetime.datetime.now().strftime('%Y%m%d%H%M%S')}"


test_session = TestSession(project_name="testingProject", run_name= run_name)

cred = DatasetCreds(arn="arn:aws:iam::527593518644:role/model-distribution")

raga_dataset = Dataset(test_session=test_session, 
                       name="uat", 
                       data=raga_data_frame, 
                       schema=schema, 
                       type=DATASET_TYPE.IMAGE,
                       creds=cred)
raga_dataset.load()


model_exe_fun = ModelExecutorFactory().get_model_executor(test_session=test_session, 
                                                          model_name="Signzy Embedding Model", 
                                                          version="0.2.0")

df = model_exe_fun.execute(init_args={"device": "cpu"}, 
                           execution_args={"input_columns":{"img_paths":"ImageUri"}, 
                                           "output_columns":{"embedding":"ImageEmbedding"},
                                           "column_schemas":{"embedding":ImageEmbeddingSchemaElement(model="Signzy Embedding Model")}}, 
                           data_frame=raga_dataset)

raga_dataset.load()